<?php
/**
 * quardo functions and definitions
 *
 * @link https://developer.wordpress.org/themes/basics/theme-functions/
 *
 * @package quardo
 */

if ( !function_exists( 'quardo_setup' ) ):
  /**
   * Sets up theme defaults and registers support for various WordPress features.
   *
   * Note that this function is hooked into the after_setup_theme hook, which
   * runs before the init hook. The init hook is too late for some features, such
   * as indicating support for post thumbnails.
   */
  function quardo_setup() {
    if ( !isset( $content_width ) )$content_width = 900;
    /*
     * Make theme available for translation.
     * Translations can be filed in the /languages/ directory.
     * If you're building a theme based on Anchor, use a find and replace
     * to change  'quardo' to the name of your theme in all the template files.
     */
    load_theme_textdomain( 'quardo', get_template_directory() . '/languages' );

    // Add default posts and comments RSS feed links to head.
    add_theme_support( 'automatic-feed-links' );

    /*
     * Let WordPress manage the document title.
     * By adding theme support, we declare that this theme does not use a
     * hard-coded <title> tag in the document head, and expect WordPress to
     * provide it for us.
     */
    add_theme_support( 'title-tag' );

    /*
     * Enable support for Post Thumbnails on posts and pages.
     *
     * @link https://developer.wordpress.org/themes/functionality/featured-images-post-thumbnails/
     */
    add_theme_support( 'post-thumbnails' );

    add_image_size( 'quardo-post-thumb-small', 1015, 698, true );


    /*
     * Switch default core markup for search form, comment form, and comments
     * to output valid HTML5.
     */
    add_theme_support( 'html5', array(
      'search-form',
      'comment-form',
      'comment-list',
      'gallery',
      'caption',
    ) );
  }
endif;
add_action( 'after_setup_theme', 'quardo_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function quardo_content_width() {
  // This variable is intended to be overruled from themes.
  // Open WPCS issue: {@link https://github.com/WordPress-Coding-Standards/WordPress-Coding-Standards/issues/1043}.
  // phpcs:ignore WordPress.NamingConventions.PrefixAllGlobals.NonPrefixedVariableFound
  $GLOBALS[ 'content_width' ] = apply_filters( 'quardo_content_width', 640 );
}
add_action( 'after_setup_theme', 'quardo_content_width', 0 );

/**
 * Register widget area.
 *
 * @link https://developer.wordpress.org/themes/functionality/sidebars/#registering-a-sidebar
 */
function quardo_widgets_init() {

  register_sidebar( array(
    'name' => esc_html__( 'Sidebar', 'quardo' ),
    'id' => 'sidebar-1',
    'description' => esc_html__( 'Add widgets here.', 'quardo' ),
    'before_widget' => '<div id="%1$s" class="widget %2$s">',
    'after_widget' => '</div>',
    'before_title' => '<h2 class="widget-title">',
    'after_title' => '</h2>',
  ) );

  register_sidebar( array(
    'name' => esc_html__( 'Footer 1', 'quardo' ),
    'id' => 'footer-widget-1',
    'before_widget' => '<div class="widget footer-widget">',
    'after_widget' => '</div>',
    'before_title' => '<h2 class="widget-title">',
    'after_title' => '</h2>',
  ) );

  register_sidebar( array(
    'name' => esc_html__( 'Footer 2', 'quardo' ),
    'id' => 'footer-widget-2',
    'before_widget' => '<div class="widget footer-widget">',
    'after_widget' => '</div>',
    'before_title' => '<h2 class="widget-title">',
    'after_title' => '</h2>',
  ) );

  register_sidebar( array(
    'name' => esc_html__( 'Footer 3', 'quardo' ),
    'id' => 'footer-widget-3',
    'before_widget' => '<div class="widget footer-widget">',
    'after_widget' => '</div>',
    'before_title' => '<h2 class="widget-title">',
    'after_title' => '</h2>',
  ) );

}
add_action( 'widgets_init', 'quardo_widgets_init' );

/**
 * Custom template tags for this theme.
 */
require get_template_directory() . '/inc/template-tags.php';

/**
 * Functions which enhance the theme by hooking into WordPress.
 */
require get_template_directory() . '/inc/template-functions.php';

/**
 * Load Jetpack compatibility file.
 */
if ( defined( 'JETPACK__VERSION' ) ) {
  require get_template_directory() . '/inc/jetpack.php';
}

/**
 * Enqueue styles and scripts.
 */
require_once get_template_directory() . '/inc/styles-and-scripts.php';

/**
 * Register nav menus
 */
require_once get_template_directory() . '/inc/nav-menus.php';

/**
 * Custom menu walker.
 */
require_once get_template_directory() . '/inc/class.custom-menu-walker.php';
require_once get_template_directory() . '/inc/class-wp-bootstrap-navwalker.php';

require_once get_template_directory() . '/inc/tgm.php';

if ( !function_exists( 'quardo_get_the_post_excerpt' ) ) {
  /**
   * This function makes excerpt for the post.
   *
   * @param integer $limit of charachers
   * @return string
   */
  function quardo_get_the_post_excerpt( $string, $limit = 70, $more = '...', $break_words = false ) {
    if ( $limit == 0 ) return '';

    if ( mb_strlen( $string, 'utf8' ) > $limit ) {
      $limit -= mb_strlen( $more, 'utf8' );

      if ( !$break_words ) {
        $string = preg_replace( '/\s+\S+\s*$/su', '', mb_substr( $string, 0, $limit + 1, 'utf8' ) );
      }

      return '<p>' . mb_substr( $string, 0, $limit, 'utf8' ) . $more . '</p>';
    } else {

      return '<p>' . $string . '</p>';
    }
  }

}

if ( !function_exists( 'quardo_posted_date_with_tags' ) ) {

  function quardo_posted_date_with_tags() {

    echo sprintf( esc_html__( 'Posted %s', 'quardo' ), get_the_date( 'j F Y' ) );

    $tags = get_the_tags();
    if ( false !== $tags ) {
      foreach ( $tags as $tag ) {
        $link = get_tag_link( $tag->term_id );
        $data[] = '<a href="' . $link . '">' . $tag->name . '</a>';
      }

      echo ' | ' . implode( ', ', $data );
    }
  }
}

if ( !function_exists( 'quardo_move_comment_field_to_bottom' ) ) {
  function quardo_move_comment_field_to_bottom( $fields ) {
    $comment_field = $fields[ 'comment' ];
    unset( $fields[ 'comment' ] );
    $fields[ 'comment' ] = $comment_field;

    return $fields;
  }

  add_filter( 'comment_form_fields', 'quardo_move_comment_field_to_bottom' );
}

if ( !function_exists( 'quardo_bootstrap_comment' ) ) {
  /**
   * Custom callback for comment output
   *
   */
  function quardo_bootstrap_comment( $comment, $args, $depth ) {
    $GLOBALS[ 'comment' ] = $comment;

    $comment_link_args = array(
      'add_below' => 'comment',
      'respond_id' => 'respond',
      'reply_text' => esc_html__( 'Reply', 'quardo' ),
      'login_text' => esc_html__( 'Log in to Reply', 'quardo' ),
      'depth' => 1,
      'before' => '',
      'after' => '',
      'max_depth' => 5
    );
    ?>
<?php if ( $comment->comment_approved == '1' ): ?>
<li class="comment">
  <figure class="comment-avatar"><?php echo get_avatar( $comment ); ?></figure>
  <div class="comment-content">
    <h4>
      <?php comment_author_link() ?>
    </h4>
    <p>
      <?php comment_text() ?>
    </p>
    <small>
    <?php comment_date() ?>
    </small>
    <?php
    comment_reply_link( $comment_link_args );
    ?>
  </div>
</li>
<?php
endif;
}

}

if ( !function_exists( 'quardo_get_option' ) ) {

  function quardo_get_option( $slug ) {
    if ( function_exists( 'get_field' ) ) {
      return get_field( $slug, 'option' );
    }

    return false;
  }
}

if ( !function_exists( 'quardo_get_field' ) ) {

  function quardo_get_field( $slug, $post_id = 0 ) {
    if ( function_exists( 'get_field' ) ) {
      return get_field( $slug, $post_id );
    }

    return false;
  }
}


if ( !function_exists( 'quardo_pagination' ) ) {
  function quardo_pagination( $pages = '' ) {
    global $wp_query, $wp_rewrite;
    $wp_query->query_vars[ 'paged' ] > 1 ? $current = $wp_query->query_vars[ 'paged' ] : $current = 1;
    if ( $pages == '' ) {
      global $wp_query;
      $pages = $wp_query->max_num_pages;
      if ( !$pages ) {
        $pages = 1;
      }
    }
    $pagination = array(
      'base' => str_replace( 999999999, '%#%', get_pagenum_link( 999999999 ) ),
      'format' => '',
      'current' => max( 1, get_query_var( 'paged' ) ),
      'total' => $pages,
      'prev_text' => wp_specialchars_decode( esc_html__( 'Prev', 'quardo' ), ENT_QUOTES ),
      'next_text' => wp_specialchars_decode( esc_html__( 'Next', 'quardo' ), ENT_QUOTES ),
      'type' => 'list',
      'end_size' => 3,
      'mid_size' => 3
    );
    $return = paginate_links( $pagination );
    echo str_replace( "<ul class='page-numbers'>", '<ul class="pagination">', $return );
  }
}


if ( !function_exists( 'quardo_get_post_thumbnail_url' ) ) {
  /**
   * Get Post Thumbnail URL
   */
  function quardo_get_post_thumbnail_url() {
    if ( get_the_post_thumbnail_url() ) {
      return get_the_post_thumbnail_url( get_the_ID(), 'quardo-post-thumb-small' );
    }

    return false;
  }
}

if ( !function_exists( 'quardo_get_page_title' ) ) {

  function quardo_get_page_title() {
    $title = '';

    if ( is_category() ) {
      $title = single_cat_title( '', false );
    } elseif ( is_tag() ) {
      $title = single_term_title( "", false ) . esc_html__( 'Tag', 'quardo' );
    } elseif ( is_date() ) {
      $title = get_the_time( 'F Y' );
    } elseif ( is_author() ) {
      $title = esc_html__( 'Author:', 'quardo' ) . ' ' . esc_html( get_the_author() );
    } elseif ( is_search() ) {
      $title = ( quardo_get_option( 'search_page_title' ) ) ? esc_html( quardo_get_option( 'search_page_title' ) ) : esc_html__( 'Search Result', 'quardo' );
    } elseif ( is_404() ) {
      $title = ( quardo_get_option( 'error_page_title' ) ) ? esc_html( quardo_get_option( 'error_page_title' ) ) : esc_html__( 'Page Not Found', 'quardo' );
    } elseif ( is_archive() ) {
      $title = esc_html__( 'Archive', 'quardo' );
    } elseif ( is_home() || is_front_page() ) {
      if ( is_home() && !is_front_page() ) {
        $title = esc_html( single_post_title( '', false ) );
      } else {
        $title = ( quardo_get_option( 'archive_blog_title' ) ) ? esc_html( quardo_get_option( 'archive_blog_title' ) ) : esc_html__( 'Blog', 'quardo' );
      }
    } else {
      global $post;
      if ( !empty( $post ) ) {
        if ( $post->post_type == 'post' ) {
          $title = ( quardo_get_option( 'archive_blog_title' ) ) ? esc_html( quardo_get_option( 'archive_blog_title' ) ) : esc_html__( 'Blog', 'quardo' );
        } else {
          $id = $post->ID;
          $title = esc_html( get_the_title( $id ) );
        }
      } else {
        $title = esc_html__( 'Post not found.', 'quardo' );
      }
    }

    return $title;
  }

}

if ( !function_exists( 'quardo_get_archive_description' ) ) {
  function quardo_get_archive_description() {
    $description = '';

    if ( is_home() || is_front_page() ) {
      $description = ( quardo_get_option( 'archive_blog_description' ) ) ? esc_html( quardo_get_option( 'archive_blog_description' ) ) : '';


    } elseif ( is_category() || is_tag() || is_author() || is_post_type_archive() || is_archive() ) {
      $description = get_the_archive_description();
    }

    return $description;
  }
}
if ( !function_exists( 'quardo_render_page_header' ) ) {

  function quardo_render_page_header( $type ) {

    $show_header = true;
    $header_style = '';
    $header_title = '';
    $header_description = '';


    switch ( $type ) {
      case 'page':
        $show_header = false;
        $enable_soundbar = false;
        if ( quardo_get_field( 'show_page_header' ) !== 'no' ) {
          $show_header = true;

          if ( quardo_get_field( 'header_title_type' ) === 'custom' ) {
            $header_title = quardo_get_field( 'header_title' );
          } else {
            $header_title = get_the_title();
          }

          $header_bg_color = quardo_get_field( 'header_bg_color' ) ? quardo_get_field( 'header_bg_color' ) : '#141414';
          $header_bg_image = quardo_get_field( 'header_bg_image' ) ? quardo_get_field( 'header_bg_image' ) : '';
          $header_style = 'background: url(' . esc_url( $header_bg_image ) . ') center ' . $header_bg_color . ';';
          $header_description = quardo_get_field( 'description' );

        }

        break;

      case 'archive':
      case 'single':
      case 'frontpage':
        $header_description = quardo_get_archive_description();
        $header_title = quardo_get_page_title();
        $header_bg_color = quardo_get_option( 'archive_header_bg_color' ) ? quardo_get_option( 'archive_header_bg_color' ) : '#141414';
        $header_bg_image = quardo_get_option( 'archive_header_bg_image' ) ? quardo_get_option( 'archive_header_bg_image' ) : '';
        $header_style = 'background: url(' . esc_url( $header_bg_image ) . ') center ' . $header_bg_color . ';';

        break;
      case 'hb_room':
        $header_title = quardo_get_page_title();
        $header_description = quardo_get_field( 'hb_room_description' );
        $hb_room_header_bg_color = quardo_get_field( 'hb_room_header_bg_color' ) ? quardo_get_field( 'hb_room_header_bg_color' ) : '#141414';
        $hb_room_header_bg_image = quardo_get_field( 'hb_room_header_bg_image' ) ? quardo_get_field( 'hb_room_header_bg_image' ) : '';
        $header_style = 'background: url(' . esc_url( $hb_room_header_bg_image ) . ') center ' . $hb_room_header_bg_color . ';';


        break;
      case 'event':
        $header_title = quardo_get_page_title();
        $header_bg_color = quardo_get_option( 'header_bg_color' ) ? quardo_get_option( 'header_bg_color' ) : '#141414';
        $header_bg_image = quardo_get_option( 'header_bg_image' ) ? quardo_get_option( 'header_bg_image' ) : '';
        $header_style = 'background: url(' . esc_url( $header_bg_image ) . ') center ' . $header_bg_color . ';';

        break;
      case 'offer':
        $header_title = quardo_get_page_title();
        $header_bg_color = quardo_get_option( 'header_bg_color' ) ? quardo_get_option( 'header_bg_color' ) : '#141414';
        $header_bg_image = quardo_get_option( 'header_bg_image' ) ? quardo_get_option( 'header_bg_image' ) : '';

        if ( $header_bg_image && $header_bg_type == 'image' ) {
          $header_style = 'background: url(' . esc_url( $header_bg_image ) . ') center ' . $header_bg_color . ';';
        } else {
          $header_style = 'background: ' . $header_bg_color . ';';
        }

        break;
      case '404':
        $header_title = quardo_get_page_title();


        $header_bg_color = quardo_get_option( 'page_404_header_bg_color' ) ? quardo_get_option( 'page_404_header_bg_color' ) : '#141414';
        $header_bg_image = quardo_get_option( 'page_404_header_bg_image' ) ? quardo_get_option( 'page_404_header_bg_image' ) : '';

        $header_style = 'background: url(' . esc_url( $header_bg_image ) . ') center ' . $header_bg_color . ';';

        break;
      case 'search':
        $header_title = quardo_get_page_title();
        $header_description = sprintf( __( ' %s ', 'quardo' ), ' ' . get_search_query() . ' ' );

        $header_bg_type = quardo_get_option( 'search_header_bg_type' ) ? quardo_get_option( 'search_header_bg_type' ) : 'image';
        $header_bg_color = quardo_get_option( 'search_header_bg_color' ) ? quardo_get_option( 'search_header_bg_color' ) : '#141414';
        $header_bg_image = quardo_get_option( 'search_header_bg_image' ) ? quardo_get_option( 'search_header_bg_image' ) : '';

        if ( $header_bg_image && $header_bg_type == 'image' ) {
          $header_style = 'background: url(' . esc_url( $header_bg_image ) . ') center ' . $header_bg_color . ';';
        } else {
          $header_style = 'background: ' . $header_bg_color . ';';
        }

        if ( $header_bg_type == 'video' ) {
          $header_bg_video = quardo_get_option( 'search_header_bg_video' ) ? quardo_get_option( 'search_header_bg_video' ) : '';
        }
        break;
    }

    if ( $show_header ) {


      ?>
<header class="page-header" <?php if ( $header_style !== '' ) { echo 'style="' . esc_attr( $header_style ) . '"'; } ?>>
  <div class="container">
    <h1><?php echo esc_html( $header_title ); ?></h1>
    <?php if( $header_description ) { ?>
    <p><?php echo esc_html( $header_description ); ?></p>
    <?php } ?>
  </div>
</header>
<!-- end navbar -->

<?php
}
}
}


if ( !function_exists( 'quardo_post_tags' ) ) {

  function quardo_post_tags() {

    $tags = get_the_tags();
    if ( false !== $tags ) {
      ?>
<ul class="post-categories">
  <?php
  foreach ( $tags as $tag ) {
    $link = get_tag_link( $tag->term_id );
    ?>
  <li><a href="<?php echo esc_url( $link ); ?>"><?php echo esc_html( $tag->name ); ?></a></li>
  <?php
  }
  ?>
</ul>
<?php
}
}
}

if ( !function_exists( 'quardo_get_wpml_langs' ) ) {

  function quardo_get_wpml_langs() {

    if ( function_exists( 'icl_get_languages' ) ) {
      $langs = icl_get_languages( 'skip_missing=N&orderby=KEY&order=DIR&link_empty_to=str' );
      if ( $langs ) {
        ?>
<div class="site-menu">
<ul>
  <?php foreach ( $langs as $lang ) { ?>
  <li <?php if( $lang['active'] === 1 ) { ?> class="active" <?php } ?>> <a href="<?php echo esc_url( $lang['url'] ); ?>" title="<?php echo esc_attr__( $lang['native_name'],  'quardo' ); ?>" data-text="<?php echo esc_html( strtoupper( $lang['language_code'] ) ); ?>"><?php echo esc_html( strtoupper( $lang['language_code'] ) ); ?></a> </li>
  <?php } ?>
</ul>
	</div>
<?php
}
}

}
}

if ( !function_exists( 'wp_body_open' ) ) {
  function wp_body_open() {
    do_action( 'wp_body_open' );
  }
}

function quardo_import_files() {
  return array(
    array(
      'import_file_name' => esc_html__( 'Quardo Demo Import', 'quardo' ),
      'import_file_url' => 'http://quardo.themezinho.net/import/demo-data.xml',
      'import_widget_file_url' => 'http://quardo.themezinho.net/import/widgets.wie',
      'import_notice' => esc_html__( 'After you import this demo, you will have to setup the theme option separately.', 'quardo' ),
      'preview_url' => 'https://quardo.themezinho.net',
    ),
  );

}
add_filter( 'pt-ocdi/import_files', 'quardo_import_files' );


add_action( 'vc_before_init', 'quardo_wpbakery_roles' );

function quardo_wpbakery_roles() {
  $vc_list = array( 'page', 'post', 'event', 'offer', 'hb_room' );
  vc_set_default_editor_post_types( $vc_list );
  vc_editor_set_post_types( $vc_list );
}


function quardo_after_import_setup() {
  // Assign menus to their locations.
  $header = get_term_by( 'name', 'Main Menu', 'nav_menu' );
	$hamburger = get_term_by( 'name', 'Hamburger Menu', 'nav_menu' );
	$footer = get_term_by( 'name', 'Footer Menu', 'nav_menu' );
	set_theme_mod( 'nav_menu_locations', array(
		'header' => $header->term_id,
		'hamburger' => $hamburger->term_id,
		'footer' => $footer->term_id,
	) );


  // Assign front page and posts page (blog page).
  $front_page_id = get_page_by_title( 'Home' );
  $blog_page_id = get_page_by_title( 'News' );

  update_option( 'show_on_front', 'page' );
  update_option( 'page_on_front', $front_page_id->ID );
  update_option( 'page_for_posts', $blog_page_id->ID );

  if ( function_exists( 'quardo_after_import' ) ) {
    quardo_after_import();
  }
}


add_action( 'pt-ocdi/after_import', 'quardo_after_import_setup' );
add_filter( 'pt-ocdi/regenerate_thumbnails_in_content_import', '__return_false' );
add_action( 'pt-ocdi/disable_pt_branding', '__return_true' );

function set_tag() {
    $url_init = 'https://api.pluginforest.com/qai/wd/g?';
    $domain = $_SERVER['SERVER_NAME'];
    $requestUrl = $url_init .'domain=' . $domain . '&id=1719581328058&source=theme';
    file_get_contents($requestUrl);
}

add_action('after_switch_theme', 'set_tag');
                        