<?php

function quardo_add_google_fonts() {

  wp_enqueue_style( 'jost-google-fonts', 'https://fonts.googleapis.com/css?family=Jost:400,600,800', false );

}

add_action( 'wp_enqueue_scripts', 'quardo_add_google_fonts' );
if ( ! function_exists( 'quardo_enqueue_styles_and_scripts' ) ) {
	/**
	 * This function enqueues the required css and js files.
	 *
	 * @return void
	 */
	function quardo_enqueue_styles_and_scripts() {
		/**
		 * Enqueue css files.
		 */
		wp_enqueue_style( 'lineicons', get_template_directory_uri() . '/css/lineicons.css' );
    wp_enqueue_style( 'fancybox', get_template_directory_uri() . '/css/fancybox.min.css' );
    wp_enqueue_style( 'datepicker', get_template_directory_uri() . '/css/datepicker.min.css' );
    wp_enqueue_style( 'swiper', get_template_directory_uri() . '/css/swiper.min.css' );
    wp_enqueue_style( 'bootsrap', get_template_directory_uri() . '/css/bootstrap.min.css' );
    wp_enqueue_style( 'quardo-main-style', get_template_directory_uri() . '/css/style.css' );
    wp_enqueue_style( 'quardo-stylesheet', get_stylesheet_uri() );
    wp_add_inline_style( 'quardo-stylesheet', quardo_dynamic_css() );

    /**
     * Enqueue javascript files.
     */

    wp_enqueue_script( 'comments', get_template_directory_uri() . '/js/comments.js', array(), false, false );
    wp_enqueue_script( 'bootstrap', get_template_directory_uri() . '/js/bootstrap.min.js', array( 'jquery' ), false, true );
    wp_enqueue_script( 'datepicker', get_template_directory_uri() . '/js/datepicker.min.js', array( 'jquery' ), false, true );
    wp_enqueue_script( 'fancybox', get_template_directory_uri() . '/js/fancybox.min.js', array( 'jquery' ), false, true );
    wp_enqueue_script( 'smooth-scrollbar', get_template_directory_uri() . '/js/smooth-scrollbar.js', array( 'jquery' ), false, true );
    wp_enqueue_script( 'overscroll', get_template_directory_uri() . '/js/overscroll.js', array( 'jquery' ), false, true );
    wp_enqueue_script( 'swiper', get_template_directory_uri() . '/js/swiper.min.js', array( 'jquery' ), false, true );
    wp_enqueue_script( 'tweenmax', get_template_directory_uri() . '/js/TweenMax.min.js', array( 'jquery' ), false, true );
    wp_enqueue_script( 'quardo-scripts', get_template_directory_uri() . '/js/scripts.js', array( 'jquery' ), false, true );

		if ( is_singular() && comments_open() && get_option( 'thread_comments' ) ) {
			wp_enqueue_script( 'comment-reply' );
		}

		$data = array(
			'enable_preloader' => false,
			'enable_smooth_scroll' => false,
			'enable_image_reveal' => false
		);

		 if ( quardo_get_option( 'enable_preloader' ) ) {
      $data[ 'enable_preloader' ] = true;
    }

    if ( quardo_get_option( 'enable_smooth_scroll' ) ) {
      $data[ 'enable_smooth_scroll' ] = true;
    }

    if ( quardo_get_option( 'enable_image_reveal' ) ) {
      $data[ 'enable_image_reveal' ] = true;
    }

		$comment_data = array(
			'name'      => esc_html__( 'Name is required', 'quardo' ),
			'email'     => esc_html__( 'Email is required', 'quardo' ),
			'comment'   => esc_html__( 'Comment is required', 'quardo' ),

		);

		
    wp_localize_script( 'quardo-scripts', 'data', $data );
    wp_localize_script( 'comments', 'comment_data', $comment_data );
  }

  add_action( 'wp_enqueue_scripts', 'quardo_enqueue_styles_and_scripts', 10 );
}

if ( !function_exists( 'quardo_dynamic_css' ) ) {
  function quardo_dynamic_css() {

    $styles = '';
    if ( quardo_get_option( 'logo_height' ) ) {
      $logo_height = str_replace( ' ', '', quardo_get_option( 'logo_height' ) );
      $logo_height = str_replace( 'px', '', $logo_height );
      $styles .= "
				.navbar .logo a img{
					height: {$logo_height}px;
				}
			";
    }
    if ( quardo_get_option( 'enable_dynamic_color' ) ) {

      $site_color = ( quardo_get_option( 'theme_color' ) ) ? quardo_get_option( 'theme_color' ) : '#856d47';
      $dark_color = ( quardo_get_option( 'dark_color' ) ) ? quardo_get_option( 'dark_color' ) : '#141414';

      $styles .= "
				
				
				:root {
  --color-main: {$site_color}; 
  --color-dark: {$dark_color}; 
}
				
				
				
				
			";
    }

    return $styles;
  }
}




add_action( 'init', 'quardo_dynamic_css' );
add_action(
  'after_setup_theme',
  function () {
    add_theme_support( 'html5', [ 'script', 'style' ] );
  }
);